@@ -10,7 +10,7 @@ use PPI 1.113;
 use PPI::Document;
 use Readonly;
 
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.0.2';
 
 Readonly::Scalar my $ALL_NEWLINES_REGEX =>
     qr/ ( \Q$INPUT_RECORD_SEPARATOR\E ) /sxm;
@@ -429,7 +429,14 @@ sub _rewrite_moose_method_modifiers {
 
     for (@method_modifiers) {
         my ($old_stmt, @children) = @$_;
-        my $name = '_' . $children[0]->literal . '_' . $children[1]->literal;
+        my $name = '_' . $children[0]->literal . '_';
+        if ( $children[1]->can('literal') ) {
+            $name .= $children[1]->literal;
+        }
+        else {
+            my $string = $children[1]->string;
+            $name .= $string;
+        }
         my $new_stmt = PPI::Statement::Sub->new();
         $new_stmt->add_element(PPI::Token::Word->new('sub'));
         $new_stmt->add_element(PPI::Token::Whitespace->new(' '));
@@ -668,7 +675,7 @@ Arrayref of unique packages found in the file.
 =head2 path
 
 Either the path to the file, or a scalar ref if that was supplied
-instaed of a path.
+instead of a path.
 
 =head2 subs
 
@@ -694,7 +701,7 @@ for example C<foo> and C<bar> are hash keys in the following:
 
   { foo => 123, bar => $a }
  
-Copied and somehwat simplified from
+Copied and somewhat simplified from
 http://search.cpan.org/src/THALJEF/Perl-Critic-0.19/lib/Perl/Critic/Utils.pm
 See L<Perl::Critic::Utils|Perl::Critic::Utils>.
 
@@ -734,7 +741,7 @@ http://rt.cpan.org/NoAuth/Bugs.html?Dist=Perl-Metrics-Simple
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2006-2009 by Eigenstate Consulting, LLC.
+Copyright (c) 2006-2021 by Eigenstate Consulting, LLC.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
